Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2931)

Unified Diff: chrome/browser/ui/cocoa/omnibox/omnibox_popup_view_mac.h

Issue 1099403005: [AiS] changing mac omnibox suggestions form NSMatrix to NSTableView (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/cocoa/omnibox/omnibox_popup_view_mac.h
diff --git a/chrome/browser/ui/cocoa/omnibox/omnibox_popup_view_mac.h b/chrome/browser/ui/cocoa/omnibox/omnibox_popup_view_mac.h
index 1c833c47e943f807e24690bdb53cd2c39d73cebc..8f38a4e9aa03f6ec33786008920b6a891bb49bee 100644
--- a/chrome/browser/ui/cocoa/omnibox/omnibox_popup_view_mac.h
+++ b/chrome/browser/ui/cocoa/omnibox/omnibox_popup_view_mac.h
@@ -23,7 +23,7 @@ class OmniboxView;
// Implements OmniboxPopupView using a raw NSWindow containing an
// NSTableView.
class OmniboxPopupViewMac : public OmniboxPopupView,
- public OmniboxPopupMatrixDelegate {
+ public OmniboxPopupTableDelegate {
public:
OmniboxPopupViewMac(OmniboxView* omnibox_view,
OmniboxEditModel* edit_model,
@@ -32,7 +32,7 @@ class OmniboxPopupViewMac : public OmniboxPopupView,
// Overridden from OmniboxPopupView:
bool IsOpen() const override;
- void InvalidateLine(size_t line) override {}
+ void InvalidateLine(size_t line) override;
void UpdatePopupAppearance() override;
gfx::Rect GetTargetBounds() override;
// This is only called by model in SetSelectedLine() after updating
@@ -40,13 +40,13 @@ class OmniboxPopupViewMac : public OmniboxPopupView,
void PaintUpdatesNow() override;
void OnDragCanceled() override {}
- // Overridden from OmniboxPopupMatrixDelegate:
- void OnMatrixRowSelected(OmniboxPopupMatrix* matrix, size_t row) override;
- void OnMatrixRowClicked(OmniboxPopupMatrix* matrix, size_t row) override;
- void OnMatrixRowMiddleClicked(OmniboxPopupMatrix* matrix,
- size_t row) override;
-
- OmniboxPopupMatrix* matrix() { return matrix_; }
dschuyler 2015/04/24 18:43:08 This wasn't being used.
+ // Overridden from OmniboxPopupTableDelegate:
+ void OnTableRowSelected(OmniboxPopupTableView* table_view,
+ size_t row) override;
+ void OnTableRowClicked(OmniboxPopupTableView* table_view,
+ size_t row) override;
+ void OnTableRowMiddleClicked(OmniboxPopupTableView* table_view,
+ size_t row) override;
protected:
// Gets the autocomplete results. This is virtual so that it can be overriden
@@ -58,12 +58,12 @@ class OmniboxPopupViewMac : public OmniboxPopupView,
void CreatePopupIfNeeded();
// Calculate the appropriate position for the popup based on the
// field's screen position and the given target for the matrix
// height, and makes the popup visible. Animates to the new frame
// if the popup shrinks, snaps to the new frame if the popup grows,
// allows existing animations to continue if the size doesn't
// change.
- void PositionPopup(const CGFloat matrixHeight);
+ void PositionPopup(const CGFloat tableHeight);
// Returns the NSImage that should be used as an icon for the given match.
NSImage* ImageForMatch(const AutocompleteMatch& match);
@@ -75,11 +75,11 @@ class OmniboxPopupViewMac : public OmniboxPopupView,
scoped_ptr<OmniboxPopupModel> model_;
NSTextField* field_; // owned by tab controller
// Child window containing a matrix which implements the popup.
base::scoped_nsobject<NSWindow> popup_;
NSRect target_popup_frame_;
- base::scoped_nsobject<OmniboxPopupMatrix> matrix_;
+ base::scoped_nsobject<OmniboxPopupTableView> table_view_;
base::scoped_nsobject<NSView> top_separator_view_;
base::scoped_nsobject<NSView> bottom_separator_view_;
base::scoped_nsobject<NSBox> background_view_;
@@ -58,12 +58,12 @@ class OmniboxPopupViewMac : public OmniboxPopupView,
void CreatePopupIfNeeded();
// Calculate the appropriate position for the popup based on the
- // field's screen position and the given target for the matrix
+ // field's screen position and the given target for the table view
// height, and makes the popup visible. Animates to the new frame
// if the popup shrinks, snaps to the new frame if the popup grows,
@@ -75,11 +75,11 @@ class OmniboxPopupViewMac : public OmniboxPopupView,
scoped_ptr<OmniboxPopupModel> model_;
NSTextField* field_; // owned by tab controller
- // Child window containing a matrix which implements the popup.
+ // Child window containing a table view which implements the popup.
base::scoped_nsobject<NSWindow> popup_;
NSRect target_popup_frame_;

Powered by Google App Engine
This is Rietveld 408576698